pub struct CGEvent { /* private fields */ }CGEventTypes only.Expand description
Implementations
Sourceimpl CGEvent
impl CGEvent
pub fn new(source: Option<&CGEventSource>) -> Option<CFRetained<CGEvent>>
CGEvent only.pub fn new_data( allocator: Option<&CFAllocator>, event: Option<&CGEvent>, ) -> Option<CFRetained<CFData>>
CGEvent only.pub fn from_data( allocator: Option<&CFAllocator>, data: Option<&CFData>, ) -> Option<CFRetained<CGEvent>>
CGEvent only.pub fn new_mouse_event( source: Option<&CGEventSource>, mouse_type: CGEventType, mouse_cursor_position: CGPoint, mouse_button: CGMouseButton, ) -> Option<CFRetained<CGEvent>>
CGEvent only.pub fn new_keyboard_event( source: Option<&CGEventSource>, virtual_key: CGKeyCode, key_down: bool, ) -> Option<CFRetained<CGEvent>>
CGEvent and CGRemoteOperation only.pub fn new_scroll_wheel_event2( source: Option<&CGEventSource>, units: CGScrollEventUnit, wheel_count: u32, wheel1: i32, wheel2: i32, wheel3: i32, ) -> Option<CFRetained<CGEvent>>
CGEvent only.pub fn new_copy(event: Option<&CGEvent>) -> Option<CFRetained<CGEvent>>
CGEvent only.pub fn new_source_from_event( event: Option<&CGEvent>, ) -> Option<CFRetained<CGEventSource>>
CGEvent only.pub fn set_source(event: Option<&CGEvent>, source: Option<&CGEventSource>)
CGEvent only.pub fn type(event: Option<&CGEvent>) -> CGEventType
CGEvent only.pub fn set_type(event: Option<&CGEvent>, type: CGEventType)
CGEvent only.pub fn timestamp(event: Option<&CGEvent>) -> CGEventTimestamp
CGEvent only.pub fn set_timestamp(event: Option<&CGEvent>, timestamp: CGEventTimestamp)
CGEvent only.pub fn location(event: Option<&CGEvent>) -> CGPoint
CGEvent only.pub fn unflipped_location(event: Option<&CGEvent>) -> CGPoint
CGEvent only.pub fn set_location(event: Option<&CGEvent>, location: CGPoint)
CGEvent only.pub fn flags(event: Option<&CGEvent>) -> CGEventFlags
CGEvent only.pub fn set_flags(event: Option<&CGEvent>, flags: CGEventFlags)
CGEvent only.Sourcepub unsafe fn keyboard_get_unicode_string(
event: Option<&CGEvent>,
max_string_length: c_ulong,
actual_string_length: *mut c_ulong,
unicode_string: *mut u16,
)
Available on crate feature CGEvent only.
pub unsafe fn keyboard_get_unicode_string( event: Option<&CGEvent>, max_string_length: c_ulong, actual_string_length: *mut c_ulong, unicode_string: *mut u16, )
CGEvent only.Safety
actual_string_lengthmust be a valid pointer or null.unicode_stringmust be a valid pointer or null.
Sourcepub unsafe fn keyboard_set_unicode_string(
event: Option<&CGEvent>,
string_length: c_ulong,
unicode_string: *const u16,
)
Available on crate feature CGEvent only.
pub unsafe fn keyboard_set_unicode_string( event: Option<&CGEvent>, string_length: c_ulong, unicode_string: *const u16, )
CGEvent only.Safety
unicode_string must be a valid pointer or null.
pub fn integer_value_field(event: Option<&CGEvent>, field: CGEventField) -> i64
CGEvent only.pub fn set_integer_value_field( event: Option<&CGEvent>, field: CGEventField, value: i64, )
CGEvent only.pub fn double_value_field( event: Option<&CGEvent>, field: CGEventField, ) -> c_double
CGEvent only.pub fn set_double_value_field( event: Option<&CGEvent>, field: CGEventField, value: c_double, )
CGEvent only.Sourcepub unsafe fn tap_create(
tap: CGEventTapLocation,
place: CGEventTapPlacement,
options: CGEventTapOptions,
events_of_interest: CGEventMask,
callback: CGEventTapCallBack,
user_info: *mut c_void,
) -> Option<CFRetained<CFMachPort>>
Available on crate feature CGEvent only.
pub unsafe fn tap_create( tap: CGEventTapLocation, place: CGEventTapPlacement, options: CGEventTapOptions, events_of_interest: CGEventMask, callback: CGEventTapCallBack, user_info: *mut c_void, ) -> Option<CFRetained<CFMachPort>>
CGEvent only.Safety
callbackmust be implemented correctly.user_infomust be a valid pointer or null.
Sourcepub unsafe fn tap_create_for_psn(
process_serial_number: NonNull<c_void>,
place: CGEventTapPlacement,
options: CGEventTapOptions,
events_of_interest: CGEventMask,
callback: CGEventTapCallBack,
user_info: *mut c_void,
) -> Option<CFRetained<CFMachPort>>
Available on crate feature CGEvent only.
pub unsafe fn tap_create_for_psn( process_serial_number: NonNull<c_void>, place: CGEventTapPlacement, options: CGEventTapOptions, events_of_interest: CGEventMask, callback: CGEventTapCallBack, user_info: *mut c_void, ) -> Option<CFRetained<CFMachPort>>
CGEvent only.Safety
process_serial_numbermust be a valid pointer.callbackmust be implemented correctly.user_infomust be a valid pointer or null.
Sourcepub unsafe fn tap_create_for_pid(
pid: pid_t,
place: CGEventTapPlacement,
options: CGEventTapOptions,
events_of_interest: CGEventMask,
callback: CGEventTapCallBack,
user_info: *mut c_void,
) -> Option<CFRetained<CFMachPort>>
Available on crate features CGEvent and libc only.
pub unsafe fn tap_create_for_pid( pid: pid_t, place: CGEventTapPlacement, options: CGEventTapOptions, events_of_interest: CGEventMask, callback: CGEventTapCallBack, user_info: *mut c_void, ) -> Option<CFRetained<CFMachPort>>
CGEvent and libc only.Safety
callbackmust be implemented correctly.user_infomust be a valid pointer or null.
pub fn tap_enable(tap: &CFMachPort, enable: bool)
CGEvent only.pub fn tap_is_enabled(tap: &CFMachPort) -> bool
CGEvent only.Sourcepub unsafe fn tap_post_event(proxy: CGEventTapProxy, event: Option<&CGEvent>)
Available on crate feature CGEvent only.
pub unsafe fn tap_post_event(proxy: CGEventTapProxy, event: Option<&CGEvent>)
CGEvent only.Safety
proxy must be a valid pointer or null.
pub fn post(tap: CGEventTapLocation, event: Option<&CGEvent>)
CGEvent only.Sourcepub unsafe fn post_to_psn(
process_serial_number: *mut c_void,
event: Option<&CGEvent>,
)
Available on crate feature CGEvent only.
pub unsafe fn post_to_psn( process_serial_number: *mut c_void, event: Option<&CGEvent>, )
CGEvent only.Safety
process_serial_number must be a valid pointer or null.
pub fn post_to_pid(pid: pid_t, event: Option<&CGEvent>)
CGEvent and libc only.Methods from Deref<Target = CFType>
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: ConcreteType,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: ConcreteType,
Attempt to downcast the type to that of type T.
This is the reference-variant. Use CFRetained::downcast if you
want to convert a retained type. See also ConcreteType for more
details on which types support being converted to.
Sourcepub fn retain_count(&self) -> usize
pub fn retain_count(&self) -> usize
Get the reference count of the object.
This function may be useful for debugging. You normally do not use this function otherwise.
Beware that some things (like CFNumbers, small CFStrings etc.) may
not have a normal retain count for optimization purposes, and can
return usize::MAX in that case.