pub struct CGPDFDocument { /* private fields */ }CGPDFDocument only.Expand description
Implementations
Sourceimpl CGPDFDocument
impl CGPDFDocument
pub fn with_provider( provider: Option<&CGDataProvider>, ) -> Option<CFRetained<CGPDFDocument>>
CGDataProvider only.pub fn with_url(url: Option<&CFURL>) -> Option<CFRetained<CGPDFDocument>>
Sourcepub unsafe fn version(
document: Option<&CGPDFDocument>,
major_version: NonNull<c_int>,
minor_version: NonNull<c_int>,
)
pub unsafe fn version( document: Option<&CGPDFDocument>, major_version: NonNull<c_int>, minor_version: NonNull<c_int>, )
Safety
major_versionmust be a valid pointer.minor_versionmust be a valid pointer.
pub fn is_encrypted(document: Option<&CGPDFDocument>) -> bool
Sourcepub unsafe fn unlock_with_password(
document: Option<&CGPDFDocument>,
password: NonNull<c_char>,
) -> bool
pub unsafe fn unlock_with_password( document: Option<&CGPDFDocument>, password: NonNull<c_char>, ) -> bool
Safety
password must be a valid pointer.
pub fn is_unlocked(document: Option<&CGPDFDocument>) -> bool
pub fn allows_printing(document: Option<&CGPDFDocument>) -> bool
pub fn allows_copying(document: Option<&CGPDFDocument>) -> bool
pub fn number_of_pages(document: Option<&CGPDFDocument>) -> usize
pub fn page( document: Option<&CGPDFDocument>, page_number: usize, ) -> Option<CFRetained<CGPDFPage>>
CGPDFPage only.pub fn catalog(document: Option<&CGPDFDocument>) -> CGPDFDictionaryRef
CGPDFDictionary only.pub fn info(document: Option<&CGPDFDocument>) -> CGPDFDictionaryRef
CGPDFDictionary only.pub fn id(document: Option<&CGPDFDocument>) -> CGPDFArrayRef
CGPDFArray only.Sourceimpl CGPDFDocument
impl CGPDFDocument
pub fn outline(&self) -> Option<CFRetained<CFDictionary>>
pub fn access_permissions(&self) -> CGPDFAccessPermissions
pub fn media_box(document: Option<&CGPDFDocument>, page: c_int) -> CGRect
No longer supported
pub fn crop_box(document: Option<&CGPDFDocument>, page: c_int) -> CGRect
No longer supported
pub fn bleed_box(document: Option<&CGPDFDocument>, page: c_int) -> CGRect
No longer supported
pub fn trim_box(document: Option<&CGPDFDocument>, page: c_int) -> CGRect
No longer supported
pub fn art_box(document: Option<&CGPDFDocument>, page: c_int) -> CGRect
No longer supported
pub fn rotation_angle(document: Option<&CGPDFDocument>, page: c_int) -> c_int
No longer supported
Methods from Deref<Target = CFType>
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: ConcreteType,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: ConcreteType,
Attempt to downcast the type to that of type T.
This is the reference-variant. Use CFRetained::downcast if you
want to convert a retained type. See also ConcreteType for more
details on which types support being converted to.
Sourcepub fn retain_count(&self) -> usize
pub fn retain_count(&self) -> usize
Get the reference count of the object.
This function may be useful for debugging. You normally do not use this function otherwise.
Beware that some things (like CFNumbers, small CFStrings etc.) may
not have a normal retain count for optimization purposes, and can
return usize::MAX in that case.