pub struct CGColorSpace { /* private fields */ }Available on crate feature
CGColorSpace only.Expand description
Implementations
Sourceimpl CGColorSpace
impl CGColorSpace
pub fn new_device_gray() -> Option<CFRetained<CGColorSpace>>
pub fn new_device_rgb() -> Option<CFRetained<CGColorSpace>>
pub fn new_device_cmyk() -> Option<CFRetained<CGColorSpace>>
Sourcepub unsafe fn with_icc_data(
data: Option<&CFType>,
) -> Option<CFRetained<CGColorSpace>>
pub unsafe fn with_icc_data( data: Option<&CFType>, ) -> Option<CFRetained<CGColorSpace>>
Safety
data should be of the correct type.
Sourcepub unsafe fn new_icc_based(
n_components: usize,
range: *const CGFloat,
profile: Option<&CGDataProvider>,
alternate: Option<&CGColorSpace>,
) -> Option<CFRetained<CGColorSpace>>
Available on crate feature CGDataProvider only.
pub unsafe fn new_icc_based( n_components: usize, range: *const CGFloat, profile: Option<&CGDataProvider>, alternate: Option<&CGColorSpace>, ) -> Option<CFRetained<CGColorSpace>>
CGDataProvider only.Safety
range must be a valid pointer or null.
Sourcepub unsafe fn new_indexed(
base_space: Option<&CGColorSpace>,
last_index: usize,
color_table: *const c_uchar,
) -> Option<CFRetained<CGColorSpace>>
pub unsafe fn new_indexed( base_space: Option<&CGColorSpace>, last_index: usize, color_table: *const c_uchar, ) -> Option<CFRetained<CGColorSpace>>
Safety
color_table must be a valid pointer or null.
pub fn new_pattern( base_space: Option<&CGColorSpace>, ) -> Option<CFRetained<CGColorSpace>>
Sourceimpl CGColorSpace
impl CGColorSpace
pub fn with_name(name: Option<&CFString>) -> Option<CFRetained<CGColorSpace>>
pub fn get_name(space: Option<&CGColorSpace>) -> Option<CFRetained<CFString>>
pub fn name(space: Option<&CGColorSpace>) -> Option<CFRetained<CFString>>
Sourceimpl CGColorSpace
impl CGColorSpace
pub fn number_of_components(space: Option<&CGColorSpace>) -> usize
pub fn model(space: Option<&CGColorSpace>) -> CGColorSpaceModel
pub fn base_color_space( space: Option<&CGColorSpace>, ) -> Option<CFRetained<CGColorSpace>>
pub fn copy_base_color_space(&self) -> CFRetained<CGColorSpace>
pub fn color_table_count(space: Option<&CGColorSpace>) -> usize
Sourcepub unsafe fn color_table(space: Option<&CGColorSpace>, table: *mut u8)
pub unsafe fn color_table(space: Option<&CGColorSpace>, table: *mut u8)
Safety
table must be a valid pointer or null.
pub fn icc_data(space: Option<&CGColorSpace>) -> Option<CFRetained<CFData>>
pub fn is_wide_gamut_rgb(&self) -> bool
pub fn is_hdr(&self) -> bool
pub fn uses_itur_2100_tf(&self) -> bool
pub fn is_pq_based(&self) -> bool
pub fn is_hlg_based(&self) -> bool
pub fn supports_output(&self) -> bool
pub fn property_list(&self) -> Option<CFRetained<CFPropertyList>>
Sourcepub unsafe fn with_property_list(
plist: &CFPropertyList,
) -> Option<CFRetained<CGColorSpace>>
pub unsafe fn with_property_list( plist: &CFPropertyList, ) -> Option<CFRetained<CGColorSpace>>
Safety
plist should be of the correct type.
pub fn uses_extended_range(&self) -> bool
pub fn linearized(&self) -> Option<CFRetained<CGColorSpace>>
pub fn extended(&self) -> Option<CFRetained<CGColorSpace>>
pub fn extended_linearized(&self) -> Option<CFRetained<CGColorSpace>>
pub fn copy_with_standard_range(&self) -> CFRetained<CGColorSpace>
pub fn with_icc_profile( data: Option<&CFData>, ) -> Option<CFRetained<CGColorSpace>>
👎Deprecated: No longer supported
pub fn icc_profile(space: Option<&CGColorSpace>) -> Option<CFRetained<CFData>>
👎Deprecated: No longer supported
Sourcepub unsafe fn with_platform_color_space(
ref: *const c_void,
) -> Option<CFRetained<CGColorSpace>>
👎Deprecated: No longer supported
pub unsafe fn with_platform_color_space( ref: *const c_void, ) -> Option<CFRetained<CGColorSpace>>
Safety
ref must be a valid pointer or null.
Methods from Deref<Target = CFType>
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: ConcreteType,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: ConcreteType,
Attempt to downcast the type to that of type T.
This is the reference-variant. Use CFRetained::downcast if you
want to convert a retained type. See also ConcreteType for more
details on which types support being converted to.
Sourcepub fn retain_count(&self) -> usize
pub fn retain_count(&self) -> usize
Get the reference count of the object.
This function may be useful for debugging. You normally do not use this function otherwise.
Beware that some things (like CFNumbers, small CFStrings etc.) may
not have a normal retain count for optimization purposes, and can
return usize::MAX in that case.